@@ -1,9 +1,9 @@
 /*
- * $Id: timebox.c,v 1.69 2020/11/23 09:04:00 tom Exp $
+ * $Id: timebox.c,v 1.72 2022/04/03 22:39:10 tom Exp $
  *
  *  timebox.c -- implements the timebox dialog
  *
- *  Copyright 2001-2019,2020   Thomas E. Dickey
+ *  Copyright 2001-2021,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -24,8 +24,6 @@
 #include <dlg_internals.h>
 #include <dlg_keys.h>
 
-#include <time.h>
-
 #define ONE_HIGH 1
 #define ONE_WIDE 2
 #define BTN_HIGH 2
@@ -209,8 +207,12 @@ dialog_timebox(const char *title,
 #endif
 
     prompt = dlg_strclone(subtitle);
+    if (height > 0)
+	height += MIN_HIGH;
     dlg_auto_size(title, prompt, &height, &width, MIN_HIGH, MIN_WIDE);
 
+    if (width < MIN_WIDE)
+	width = MIN_WIDE;
     dlg_button_layout(buttons, &width);
     dlg_print_size(height, width);
     dlg_ctl_size(height, width);
